@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-__version__ = '2.0.0'
+__version__ = '2.1.0'
 __versionfull__ = __version__
 
 import functools
@@ -16,11 +16,28 @@ from django.utils.encoding import force_bytes
 logger = logging.getLogger(__name__)
 
 
+class DefaultCacheObject(object):
+    pass
+
+
+DEFAULT_CACHE_OBJECT = DefaultCacheObject()
+
+
+def _get_argspec(f):
+    try:
+        argspec = inspect.getargspec(f)
+    except ValueError:
+        # this can happen in python 3.5 when
+        # function has keyword-only arguments or annotations
+        argspec = inspect.getfullargspec(f)
+    return argspec
+
+
 def function_namespace(f, args=None):
     """
     Attempts to returns unique namespace for function
     """
-    m_args = inspect.getargspec(f)[0]
+    m_args = _get_argspec(f).args
     instance_token = None
 
     instance_self = getattr(f, '__self__', None)
@@ -69,13 +86,15 @@ class Memoizer(object):
     """
     This class is used to control the memoizer objects.
     """
-    def __init__(self, cache=default_cache, cache_prefix='memoize'):
+    def __init__(self, cache=default_cache, cache_prefix='memoize',
+                 default_cache_value=DEFAULT_CACHE_OBJECT):
         self.cache = cache
         self.cache_prefix = cache_prefix
+        self.default_cache_value = default_cache_value
 
     def get(self, key):
         "Proxy function for internal cache object."
-        return self.cache.get(key=key)
+        return self.cache.get(key=key, default=self.default_cache_value)
 
     def set(self, key, value, timeout=DEFAULT_TIMEOUT):
         "Proxy function for internal cache object."
@@ -204,7 +223,7 @@ class Memoizer(object):
         #: 1, b=2 is equivilant to a=1, b=2, etc.
         new_args = []
         arg_num = 0
-        argspec = inspect.getargspec(f)
+        argspec = _get_argspec(f)
 
         args_len = len(argspec.args)
         for i in range(args_len):
@@ -331,7 +350,7 @@ class Memoizer(object):
                     )
                     return f(*args, **kwargs)
 
-                if rv is None:
+                if rv == self.default_cache_value:
                     rv = f(*args, **kwargs)
                     try:
                         self.set(
